@@ -2,7 +2,7 @@ import unittest
 import datetime
 
 from arangodb.api import Client, Database, Collection, Document
-from arangodb.orm.fields import CharField, ForeignKeyField, NumberField, DatetimeField, DateField
+from arangodb.orm.fields import CharField, ForeignKeyField, NumberField, DatetimeField, DateField, BooleanField
 from arangodb.orm.models import CollectionModel
 from arangodb.query.advanced import Query, Traveser
 from arangodb.query.utils.document import create_document_from_result_dict
@@ -563,6 +563,35 @@ class CollectionModelManagerTestCase(unittest.TestCase):
 
         TestModel.destroy()
 
+    def test_retrieve_all_models_and_update_one(self):
+
+        class TestModel(CollectionModel):
+            text = CharField(null=False)
+
+        TestModel.init()
+
+        model1 = TestModel()
+        model1.text = 'aa'
+        model1.save()
+
+        model2 = TestModel()
+        model2.text = 'aa'
+        model2.save()
+
+        all_models = TestModel.objects.all()
+
+        self.assertEqual(len(all_models), 2)
+
+        model = all_models[0]
+        model.text = 'xx'
+        model.save()
+
+        all_models = TestModel.objects.all()
+
+        self.assertEqual(len(all_models), 2)
+
+        TestModel.destroy()
+
 
 class CollectionModelForeignKeyFieldTestCase(unittest.TestCase):
     def setUp(self):
@@ -609,6 +638,39 @@ class CollectionModelForeignKeyFieldTestCase(unittest.TestCase):
         TestModel.destroy()
 
 
+class BooleanFieldTestCase(unittest.TestCase):
+
+    def setUp(self):
+        pass
+
+    def tearDown(self):
+        pass
+
+    def test_basic_creation_with_default(self):
+        boolean = False
+        field = BooleanField(default=boolean)
+
+        self.assertEqual(boolean, field.boolean)
+
+    def test_equals(self):
+
+        boolean1 = BooleanField()
+        boolean1.set(True)
+
+        boolean2 = BooleanField()
+        boolean2.set(True)
+
+        self.assertEqual(boolean1, boolean2)
+
+        boolean1 = BooleanField()
+        boolean1.set(False)
+
+        boolean2 = BooleanField()
+        boolean2.set(False)
+
+        self.assertEqual(boolean1, boolean2)
+
+
 class CharFieldTestCase(unittest.TestCase):
 
     def setUp(self):
